@@ -38,5 +38,9 @@ export default class EsDomain extends aux.multipleClasses(EsLookup,EsObjectAcces
         return this.eoq2domain;
     }
 
+    getEcore(){
+        return this.esInstance.getEcore()
+    }
+
 } 
 
