@@ -1,8 +1,11 @@
-var builtInClasses=Object.values(window["Ecore"]).filter((val) => { return val.eClass?true:false })
-
 class EsUtilities{
     constructor(esDomain){
         this._esDomain=esDomain;
+        this.builtInClasses=this.getBuiltInClasses()
+    }
+
+    getBuiltInClasses(){
+        return Object.values(this._esDomain.getEcore()).filter((val) => { return val.eClass?true:false })
     }
 
     async isEClassInitialized(eClass)
@@ -26,7 +29,7 @@ class EsUtilities{
     isLocalEcoreElement(name){
         let res=false;
         if(name=='EInteger') name='EInt'
-        var keys=Object.keys(window["Ecore"]);
+        var keys=Object.keys(this._esDomain.getEcore());
         if( keys.includes(name) )
         {
             res=true;
@@ -37,10 +40,10 @@ class EsUtilities{
     getLocalEcoreElement(name){
         let res=null;
         if(name=='EInteger') name='EInt'
-        var keys=Object.keys(window["Ecore"]);
+        var keys=Object.keys(this._esDomain.getEcore());
         if( keys.includes(name) )
         {
-            res=window["Ecore"][name]
+            res=this._esDomain.getEcore()[name]
         }
         return res;
     }
@@ -178,9 +181,8 @@ class EsUtilities{
     }
 
     isBuiltInClass(eClass)
-    {
-        var Ecore=window["Ecore"]        
-        let res=builtInClasses.find((clazz) => { return clazz == eClass})?true:false
+    { 
+        let res=this.builtInClasses.find((clazz) => { return clazz == eClass})?true:false
         return res
     }
 
